@@ -15,7 +15,10 @@ try:
     session = boto3.session.Session()
     client = session.client(
         service_name='secretsmanager',
-        region_name=region_name
+        region_name=region_name,
+        aws_access_key_id=os.environ['ACCESS_KEY'],
+        aws_secret_access_key=os.environ['SECRET_KEY']
+
     )
 
     response = client.get_secret_value(
